@@ -65,7 +65,7 @@ def save_downsampled_file(id_mark: str,
     root_group = output.init_file(file_name, dimensions, obj.data, uuid)
     _augment_global_attributes(root_group)
     uuid = root_group.file_uuid
-    output.add_file_type(root_group, id_mark.split('-')[0])
+    root_group.cloudnet_file_type = id_mark.split('-')[0]
     root_group.title = f"Downsampled {id_mark.capitalize().replace('_', ' of ')} from {obj.dataset.location}"
     _add_source(root_group, objects, files)
     output.copy_global(obj.dataset, root_group, ('location', 'day', 'month', 'year'))
@@ -115,7 +115,7 @@ def _write_vars2nc(rootgrp: netCDF4.Dataset, cloudnet_variables: dict):
 
 def _augment_global_attributes(root_group: netCDF4.Dataset):
     root_group.Conventions = 'CF-1.8'
-    root_group.model_evaluation_version = version.__version__
+    root_group.cloudnetme_version = version.__version__
 
 
 def _add_source(root_ground: netCDF4.Dataset, objects: tuple, files: tuple):
