@@ -1,4 +1,5 @@
 import sys, os
+import logging
 import numpy as np
 import numpy.ma as ma
 import matplotlib.pyplot as plt
@@ -39,7 +40,8 @@ def generate_L3_day_plots(nc_file: str,
             product (str): Name of product wanted to plot
             model (str): Name of model which downsampling was done with
 
-            title (bool): True or False if wanted add title to subfig
+            title (bool): Show title and additional labels. Operational processing sets this to False.
+                          Default is True.
             fig_type (str, optional): Type of figure wanted to produce. Options
                                       are 'group', 'pair', 'single' and 'statistic'.
                                       Default value is 'group'
@@ -251,21 +253,35 @@ def get_statistic_plots(product: str, names: list, nc_file: str, model: str,
     """
     model_run = model
     for stat in stats:
-        variable_info = ATTRIBUTES[product]
-        fig, ax = initialize_figure(len(names) - 1, stat)
-        model_data, *axes = p_tools.read_data_characters(nc_file, names[0], model)
-        for j, name in enumerate(names):
-            data, x, y = p_tools.read_data_characters(nc_file, name, model)
-            if product == 'cf' and stat == 'error':
-                stat = 'aerror'
-            if j > 0:
-                name = ''
-                name = _get_stat_titles(name, product, variable_info)
-                day_stat = DayStatistics(stat, [product, model_name, name], model_data,
-                                         data)
-                initialize_statistic_plots(j, len(names) - 1, ax[j - 1], stat,
+        try:
+            obs_missing = False
+            model_missing = False
+            variable_info = ATTRIBUTES[product]
+            fig, ax = initialize_figure(len(names) - 1, stat)
+            model_data, *axes = p_tools.read_data_characters(nc_file, names[0], model)
+            if np.all(model_data.mask == True):
+                model_missing = True
+            for j, name in enumerate(names):
+                data, x, y = p_tools.read_data_characters(nc_file, name, model)
+                if np.all(data.mask == True):
+                    obs_missing = True
+                if model_missing and obs_missing:
+                    raise ValueError('No data in either dataset')
+                if product == 'cf' and stat == 'error':
+                    stat = 'aerror'
+                if j > 0:
+                    name = ''
+                    name = _get_stat_titles(name, product, variable_info)
+                    day_stat = DayStatistics(stat, [product, model_name, name], model_data,
+                                             data)
+                    if 'error' in stat:
+                        if np.all(day_stat.model_stat.mask == True):
+                            raise ValueError('No data to calculate relative error')
+                    initialize_statistic_plots(j, len(names) - 1, ax[j - 1], stat,
                                            day_stat, model_data, data, (x, y),
                                            variable_info, title)
+        except ValueError as e:
+            logging.error("Error: {0}".format(e))
         if stat != 'hist' and stat != 'vertical':
             casedate = cloud_plt._set_labels(fig, ax[j - 1], nc_file, sub_title=title)
         else:
@@ -335,9 +351,6 @@ def plot_data_area(ax, day_stat: DayStatistics, model: np.array, obs: np.array,
     legend_elements = [Patch(facecolor='khaki', edgecolor='k', label='Model'),
                        Patch(facecolor=cmap(0.5), edgecolor='k', label='Common'),
                        Patch(facecolor=cmap(1.), edgecolor='k', label='Observation')]
-    if len(np.unique(data)) < 4:
-        legend_elements = [Patch(facecolor='khaki', edgecolor='k', label='Original model'),
-                           Patch(facecolor=cmap(1.), edgecolor='k', label='Filtered model')]
     ax.legend(handles=legend_elements, loc='lower left', ncol=3, fontsize=12, bbox_to_anchor=(-0.005, -0.25))
 
 
@@ -389,6 +402,8 @@ def plot_vertical_profile(ax, day_stat: DayStatistics, axes: tuple,
 
 def initialize_figure(n_subplots: int, stat: str = '') -> Tuple:
     """ Set up fig and ax object, if subplot"""
+    if n_subplots <= 0:
+        n_subplots = 1
     fig, axes = plt.subplots(n_subplots, 1, figsize=(16, 4 + (n_subplots - 1) * 4.8))
     fig.subplots_adjust(left=0.06, right=0.73, hspace=0.31)
     if stat == 'area':
